<?php
/**
 * Copyright (©) 2023 Pinpoint Designs LTD. All right's reserved.
 *
 * Author: Chandravadana Kandregula
 * Code Release Version: 1.0.0
 * Website: http://www.pinpointdesigns.co.uk
 *
 * Class Data
 * @package Pinpoint\NewsletterSignup\Helper
 */
namespace Pinpoint\NewsletterSignup\Helper;

use Magento\Framework\App\Helper\AbstractHelper;
use Magento\Framework\App\Helper\Context;
use Magento\Newsletter\Model\SubscriberFactory;
use Magento\Store\Model\StoreManagerInterface;
use Magento\Customer\Model\Session;
use Magento\Customer\Api\Data\CustomerInterface;

class Data extends AbstractHelper
{
    const NEWSLETTERSIGNUP_ENABLED = 'pinpoint_newslettersignup/general/';
    const PINPOINT_SUBSCRIBE = 'pinpoint_newsletter_subscribe';

    /**
     * @var SubscriberFactory
     */
    private $subscriberFactory;
    /**
     * @var StoreManagerInterface
     */
    private $storeManager;

    /**
     * @var
     */
    private $isSubscribed;

    /**
     * @var
     */
    private $isEnabled;

    /**
     * @var
     */
    private $newsletterLabel;

    /**
     * @var
     */
    private $newsletterDefault;
    /**
     * @var Session
     */
    private $customerSession;

    /**
     * Config constructor.
     * @param Context $context
     * @param SubscriberFactory $subscriber
     * @param StoreManagerInterface $storeManager
     * @param Session $customerSession
     */
    public function __construct(
        Context $context,
        SubscriberFactory $subscriber,
        StoreManagerInterface $storeManager,
        Session $customerSession
    ) {
        parent::__construct($context);
        $this->subscriberFactory = $subscriber;
        $this->storeManager = $storeManager;
        $this->customerSession = $customerSession;
    }

    /**
     * Get module settings
     *
     * @param $key
     * @return mixed
     * @throws \Magento\Framework\Exception\NoSuchEntityException
     */
    public function getConfig($key)
    {
        return $this->scopeConfig->getValue(
            self::NEWSLETTERSIGNUP_ENABLED . $key,
            \Magento\Store\Model\ScopeInterface::SCOPE_STORE,
            $this->storeManager->getStore()->getId()
        );
    }

    /**
     * @return mixed
     * @throws \Magento\Framework\Exception\NoSuchEntityException
     */
    public function isModuleEnabled()
    {
        if (!$this->isEnabled) {
            $this->isEnabled = $this->getConfig('enabled');
        }
        return $this->isEnabled;
    }

    /**
     * @return mixed
     * @throws \Magento\Framework\Exception\NoSuchEntityException
     */
    public function getSubscriptionLabel()
    {
        if (!$this->newsletterLabel) {
            $this->newsletterLabel = $this->getConfig('checkout_label');
        }
        return $this->newsletterLabel;
    }

    /**
     * @return mixed
     * @throws \Magento\Framework\Exception\NoSuchEntityException
     */
    public function isCheckoutSubscribeDefault()
    {
        if (!$this->newsletterDefault) {
            $this->newsletterDefault = $this->getConfig('checkout_subscribe');
        }
        return $this->newsletterDefault;
    }

    /**
     * @param $email
     * @return bool
     */
    public function isEmailSubscribed($email)
    {
        if (!$this->isSubscribed) {
            $this->isSubscribed = $this->subscriberFactory->create()->loadByEmail($email)->isSubscribed();
        }
        return $this->isSubscribed;
    }

    /**
     * Check if customer subsribed
     *
     * @return bool
     */
    public function isSubscribed()
    {
        if (!$this->customerSession->isLoggedIn()) {
            return false;
        }

        /**
         * @var CustomerInterface $customer
         */
        $customer = $this->customerSession->getCustomer();
        $checkSubscriber = $this->subscriberFactory->create()->loadBySubscriberEmail($customer->getEmail(), $this->storeManager->getWebsite()->getId());

        return $checkSubscriber->isSubscribed();
    }
}
