<?php
/**
 * Copyright (©) 2023 Pinpoint Designs LTD. All right's reserved.
 *
 * Author: Chandravadana Kandregula
 * Code Release Version: 1.0.0
 * Website: http://www.pinpointdesigns.co.uk
 *
 * Class NewsletterConfigProvider
 * @package Pinpoint\NewsletterSignup\Model\Config
 */
namespace Pinpoint\NewsletterSignup\Model\Config;

use Magento\Checkout\Model\ConfigProviderInterface;
use Pinpoint\NewsletterSignup\Helper\Data;

class NewsletterConfigProvider implements ConfigProviderInterface
{
    /**
     * @var Data
     */
    private $helper;

    /**
     * NewsletterConfigProvider constructor.
     *
     * @param Data $helper
     */
    public function __construct(
        Data $helper
    ) {
        $this->helper = $helper;
    }

    /**
     * {@inheritdoc}
     */
    public function getConfig(): array
    {
        return [
            'checkoutNewsletter' => $this->getNewsletterConfig(),
        ];
    }

    /**
     * Returns newsletter config
     *
     * @return array
     * @throws \Magento\Framework\Exception\NoSuchEntityException
     */
    protected function getNewsletterConfig(): array
    {
        $newsletterConfiguration = [];
        $isNewsletterEnabled = $this->helper->isModuleEnabled();
        $newsletterConfiguration['isEnabled'] = (bool)$isNewsletterEnabled;
        return $newsletterConfiguration;
    }
}
