<?php

/**
 * Copyright (©) 2023 Pinpoint Designs LTD. All right's reserved.
 *
 * Author: Chandravadana Kandregula
 * Code Release Version: 1.0.0
 * Website: http://www.pinpointdesigns.co.uk
 *
 * Class QuoteSubmitSuccess
 * @package Pinpoint\NewsletterSignup\Observer
 */

namespace Pinpoint\NewsletterSignup\Observer;

use Magento\Framework\Event\Observer;
use Magento\Framework\Event\ObserverInterface;
use Psr\Log\LoggerInterface;
use Magento\Newsletter\Model\SubscriberFactory;
use Pinpoint\NewsletterSignup\Helper\Data;

class QuoteSubmitSuccess implements ObserverInterface
{
    /**
     * @var SubscriberFactory
     */
    private $subscriberFactory;

    /**
     * @var LoggerInterface
     */
    private $logger;

    /**
     * QuoteSubmitSuccess constructor.
     *
     * @param SubscriberFactory $subscriberFactory
     * @param LoggerInterface $logger
     */
    public function __construct(
        SubscriberFactory $subscriberFactory,
        LoggerInterface $logger
    ) {
        $this->subscriberFactory = $subscriberFactory;
        $this->logger = $logger;
    }

    /**
     * Subscribe to newsletters if the customer checked the checkbox
     *
     * @param Observer $observer
     * @return $this
     */
    public function execute(Observer $observer)
    {
        $quote = $observer->getQuote();
        if ($quote->getPayment()->getAdditionalInformation(Data::PINPOINT_SUBSCRIBE)) {
            $email = 'undefined';
            try {
                $email = $quote->getCustomerEmail();
                $this->subscriberFactory->create()->subscribe($email);
            } catch (\Exception $e) {
                $this->logger->error($e->getMessage() . ' to ' . $email);
            }
        }
        return $this;
    }
}
