<?php

/**
 * Copyright (©) 2023 Pinpoint Designs LTD. All right's reserved.
 *
 * Author: Chandravadana Kandregula
 * Code Release Version: 1.0.0
 * Website: http://www.pinpointdesigns.co.uk
 *
 * Class GuestPaymentInformation
 * @package Pinpoint\NewsletterSignup\Plugin\Checkout
 */
namespace Pinpoint\NewsletterSignup\Plugin\Checkout;

use Pinpoint\NewsletterSignup\Helper\Data;
use Magento\Checkout\Model\Session;
use Magento\Quote\Api\CartRepositoryInterface;
use Magento\Quote\Model\QuoteRepository;

class GuestPaymentInformation
{

    /**
     * @var Data
     */
    protected $helper;

    /**
     * @var CartRepositoryInterface
     */
    protected $cartRepository;

    /**
     * @var Session
     */
    private $checkoutSession;
    /**
     * @var QuoteRepository
     */
    private $quoteRepository;

    /**
     * GuestPaymentInformation constructor.
     * @param Data $newsletterSignupHelper
     * @param Session $checkoutSession
     * @param CartRepositoryInterface $cartRepository
     * @param QuoteRepository $quoteRepository
     */
    public function __construct(
        Data $newsletterSignupHelper,
        Session $checkoutSession,
        CartRepositoryInterface $cartRepository,
        QuoteRepository $quoteRepository
    ) {
        $this->helper = $newsletterSignupHelper;
        $this->cartRepository = $cartRepository;
        $this->checkoutSession = $checkoutSession;
        $this->quoteRepository = $quoteRepository;
    }

    /**
     * @param \Magento\Checkout\Api\GuestPaymentInformationManagementInterface $subject
     * @param string $cartId
     * @param string $email
     * @param \Magento\Quote\Api\Data\PaymentInterface $paymentMethod
     * @param \Magento\Quote\Api\Data\AddressInterface|null $billingAddress
     * @return void
     * @throws \Magento\Framework\Exception\LocalizedException
     * @throws \Magento\Framework\Exception\NoSuchEntityException
     * @SuppressWarnings(PHPMD.UnusedFormalParameter)
     */
    public function beforeSavePaymentInformation(
        \Magento\Checkout\Api\GuestPaymentInformationManagementInterface $subject,
        $cartId,
        $email,
        \Magento\Quote\Api\Data\PaymentInterface $paymentMethod,
        \Magento\Quote\Api\Data\AddressInterface $billingAddress = null
    ) {
        if ($this->helper->isModuleEnabled()) {
            $newsletterSubscribe = $paymentMethod->getExtensionAttributes() === null
                ? 0
                : $paymentMethod->getExtensionAttributes()->getNewsletterSubscribe();
            $quote = $this->cartRepository->get($this->checkoutSession->getQuote()->getId());
            $quote->getPayment()->setAdditionalInformation(Data::PINPOINT_SUBSCRIBE, $newsletterSubscribe);
        }
    }
}
