<?php
/**
 * Copyright (©) 2023 Pinpoint Designs LTD. All right's reserved.
 *
 * Author: Chandravadana Kandregula
 * Code Release Version: 1.0.0
 * Website: http://www.pinpointdesigns.co.uk
 *
 * Class PaymentInformation
 * @package Pinpoint\NewsletterSignup\Plugin\Checkout
 */

namespace Pinpoint\NewsletterSignup\Plugin\Checkout;

use Magento\Quote\Api\Data\AddressInterface;
use Magento\Quote\Model\QuoteRepository;
use Pinpoint\NewsletterSignup\Helper\Data;

class PaymentInformation
{
    /**
     * @var QuoteRepository
     */
    protected $quoteRepository;

    /**
     * @var Data
     */
    protected $helper;

    /**
     * PaymentInformation constructor.
     * @param Data $newsletterSignupHelper
     * @param QuoteRepository $quoteRepository
     */
    public function __construct(
        Data $newsletterSignupHelper,
        QuoteRepository $quoteRepository
    ) {
        $this->helper = $newsletterSignupHelper;
        $this->quoteRepository = $quoteRepository;
    }

    /**
     * @param \Magento\Checkout\Api\PaymentInformationManagementInterface $subject
     * @param int $cartId
     * @param \Magento\Quote\Api\Data\PaymentInterface $paymentMethod
     * @param AddressInterface|null $billingAddress
     * @return void
     * @throws \Magento\Framework\Exception\LocalizedException
     * @throws \Magento\Framework\Exception\NoSuchEntityException
     */
    public function beforeSavePaymentInformation(
        \Magento\Checkout\Api\PaymentInformationManagementInterface $subject,
        $cartId,
        \Magento\Quote\Api\Data\PaymentInterface $paymentMethod,
        AddressInterface $billingAddress = null
    ) {
        if ($this->helper->isModuleEnabled()) {
            $newsletterSubscribe = $paymentMethod->getExtensionAttributes() === null
                ? 0
                : $paymentMethod->getExtensionAttributes()->getNewsletterSubscribe();

            $quote = $this->quoteRepository->getActive($cartId);
            $quote->getPayment()->setAdditionalInformation(Data::PINPOINT_SUBSCRIBE, $newsletterSubscribe);
        }
    }

}
