<?php
/**
 * Copyright (©) 2023 Pinpoint Designs LTD. All right's reserved.
 *
 * Author: Chandravadana Kandregula
 * Code Release Version: 1.0.0
 * Website: http://www.pinpointdesigns.co.uk
 *
 * Class SubscribeLayoutProcessor
 * @package Pinpoint\NewsletterSignup\Plugin\Checkout
 */
namespace Pinpoint\NewsletterSignup\Plugin\Checkout;

use Magento\Checkout\Block\Checkout\LayoutProcessor;
use Magento\Framework\Exception\NoSuchEntityException;
use Pinpoint\NewsletterSignup\Helper\Data;
use Magento\Checkout\Model\Session;

class SubscribeLayoutProcessor
{
    /**
     * @var Data
     */
    protected $helper;

    /**
     * @var Session
     */
    private $session;

    /**
     * @param Data $helper
     * @param Session $session
     */
    public function __construct(
        Data $helper,
        Session $session
    ) {
        $this->helper = $helper;
        $this->session = $session;
    }

    /**
     * @param LayoutProcessor $subject
     * @param array $jsLayout
     * @return array
     * @throws NoSuchEntityException
     */
    public function afterProcess(
        LayoutProcessor $subject,
        array $jsLayout
    ) {
        if (!$this->helper->isModuleEnabled()) {
            return $jsLayout;
        }

        if ($this->session->getQuote()->getCustomerEmail()) {
            $isSubscribed = $this->helper->isEmailSubscribed($this->session->getQuote()->getCustomerEmail());
            if ($isSubscribed) {
                return $jsLayout;
            }
        }

        $checked = $this->helper->isCheckoutSubscribeDefault() == 2 ? 0 : 1;

        $SubscribeCheckboxField = [
            'component' => 'Magento_Ui/js/form/element/boolean',
            'config' => [
                'customScope' => 'newslettersignupCheckbox',
                'template' => 'Pinpoint_NewsletterSignup/checkout/uiform/element/newsletter-subscribe',
                'elementTmpl' => 'ui/form/element/checkbox',
                'checkoutLabel' => $this->helper->getSubscriptionLabel(),
                'checked' => $checked,
                'visible' => 1,
                'changeable' => 1,
            ],
            'provider' => 'checkoutProvider',
            'dataScope' => 'newslettersignupCheckbox.checkbox_field',
            'label' => $this->helper->getSubscriptionLabel(),
            'sortOrder' => 100
        ];

        $jsLayoutSubscribe = [
            'components' => [
                'checkout' => [
                    'children' => [
                        'steps' => [
                            'children' => [
                                'billing-step' => [
                                    'children' => [
                                        'payment' => [
                                            'children' => [
                                                'payments-list' => [
                                                    'children' => [
                                                        'before-place-order' => [
                                                            'children' => [
                                                                'newsletter-subscribe' => $SubscribeCheckboxField
                                                            ]
                                                        ]
                                                    ]
                                                ]
                                            ]
                                        ]
                                    ]
                                ]
                            ]
                        ]
                    ]
                ]
            ]
        ];

        $jsLayout = array_merge_recursive($jsLayout, $jsLayoutSubscribe);

        return $jsLayout;
    }
}
