<?php

namespace Pinpoint\NewsletterSignup\Plugin\NewsletterSignup;

use Magento\Contact\Controller\Index\Post as Subject;
use Magento\Customer\Model\Session;
use Magento\Newsletter\Model\SubscriberFactory;
use Magento\Newsletter\Model\SubscriptionManager;
use Magento\Store\Model\StoreManagerInterface;

class Post
{
    /**
     * @var SubscriberFactory
     */
    protected $subscriberFactory;

    /**
     * @var Session
     */
    protected $customerSession;
    /**
     * @var SubscriptionManager
     */
    private $subscriptionManager;
    /**
     * @var StoreManagerInterface
     */
    private $storeManager;

    /**
     * Post constructor.
     *
     * @param SubscriberFactory $subscriberFactory
     * @param SubscriptionManager $subscriptionManager
     * @param Session $customerSession
     * @param StoreManagerInterface $storeManager
     */
    public function __construct(
        SubscriberFactory $subscriberFactory,
        SubscriptionManager $subscriptionManager,
        Session $customerSession,
        StoreManagerInterface $storeManager
    ) {
        $this->subscriberFactory = $subscriberFactory;
        $this->customerSession = $customerSession;
        $this->subscriptionManager = $subscriptionManager;
        $this->storeManager = $storeManager;
    }
    
    /**
     * Override execute() to subscribe customer before send email
     *
     * @param Subject  $subject
     * @param \Closure $proceed
     *
     * @return mixed
     */
    public function aroundExecute(Subject $subject, \Closure $proceed)
    {
        if ($subject->getRequest()->isPost()) {
            $post = $subject->getRequest()->getPostValue();
            if ((boolean)$subject->getRequest()->getParam('consent') === true) {
                $this->subscriptionManager->subscribe($post['email'], $this->storeManager->getStore()->getId());
            }
        }
        return $proceed();
    }
}
